/*
Copyright 2020 The Knative Authors

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	"time"

	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	v1alpha1 "knative.dev/eventing/pkg/apis/configs/v1alpha1"
	scheme "knative.dev/eventing/pkg/client/clientset/versioned/scheme"
)

// ConfigMapPropagationsGetter has a method to return a ConfigMapPropagationInterface.
// A group's client should implement this interface.
type ConfigMapPropagationsGetter interface {
	ConfigMapPropagations(namespace string) ConfigMapPropagationInterface
}

// ConfigMapPropagationInterface has methods to work with ConfigMapPropagation resources.
type ConfigMapPropagationInterface interface {
	Create(*v1alpha1.ConfigMapPropagation) (*v1alpha1.ConfigMapPropagation, error)
	Update(*v1alpha1.ConfigMapPropagation) (*v1alpha1.ConfigMapPropagation, error)
	UpdateStatus(*v1alpha1.ConfigMapPropagation) (*v1alpha1.ConfigMapPropagation, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1alpha1.ConfigMapPropagation, error)
	List(opts v1.ListOptions) (*v1alpha1.ConfigMapPropagationList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.ConfigMapPropagation, err error)
	ConfigMapPropagationExpansion
}

// configMapPropagations implements ConfigMapPropagationInterface
type configMapPropagations struct {
	client rest.Interface
	ns     string
}

// newConfigMapPropagations returns a ConfigMapPropagations
func newConfigMapPropagations(c *ConfigsV1alpha1Client, namespace string) *configMapPropagations {
	return &configMapPropagations{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the configMapPropagation, and returns the corresponding configMapPropagation object, and an error if there is any.
func (c *configMapPropagations) Get(name string, options v1.GetOptions) (result *v1alpha1.ConfigMapPropagation, err error) {
	result = &v1alpha1.ConfigMapPropagation{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("configmappropagations").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of ConfigMapPropagations that match those selectors.
func (c *configMapPropagations) List(opts v1.ListOptions) (result *v1alpha1.ConfigMapPropagationList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha1.ConfigMapPropagationList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("configmappropagations").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested configMapPropagations.
func (c *configMapPropagations) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("configmappropagations").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a configMapPropagation and creates it.  Returns the server's representation of the configMapPropagation, and an error, if there is any.
func (c *configMapPropagations) Create(configMapPropagation *v1alpha1.ConfigMapPropagation) (result *v1alpha1.ConfigMapPropagation, err error) {
	result = &v1alpha1.ConfigMapPropagation{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("configmappropagations").
		Body(configMapPropagation).
		Do().
		Into(result)
	return
}

// Update takes the representation of a configMapPropagation and updates it. Returns the server's representation of the configMapPropagation, and an error, if there is any.
func (c *configMapPropagations) Update(configMapPropagation *v1alpha1.ConfigMapPropagation) (result *v1alpha1.ConfigMapPropagation, err error) {
	result = &v1alpha1.ConfigMapPropagation{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("configmappropagations").
		Name(configMapPropagation.Name).
		Body(configMapPropagation).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *configMapPropagations) UpdateStatus(configMapPropagation *v1alpha1.ConfigMapPropagation) (result *v1alpha1.ConfigMapPropagation, err error) {
	result = &v1alpha1.ConfigMapPropagation{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("configmappropagations").
		Name(configMapPropagation.Name).
		SubResource("status").
		Body(configMapPropagation).
		Do().
		Into(result)
	return
}

// Delete takes name of the configMapPropagation and deletes it. Returns an error if one occurs.
func (c *configMapPropagations) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("configmappropagations").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *configMapPropagations) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("configmappropagations").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched configMapPropagation.
func (c *configMapPropagations) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.ConfigMapPropagation, err error) {
	result = &v1alpha1.ConfigMapPropagation{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("configmappropagations").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
